==> Cosmos.uv3.02.tar.gz: cosmos/Zevhnv.h <==
c                    variables in Event generator
        record /ptcl/ Pjlab,     ! projectile in lab.
     *                Pjtatr,    ! projectile in target at rest system
     *                Pjcms,     ! projectile in cms
     *                Rpjlab,    ! recoiled proj. in lab
     *                Rpjtatr,   ! recoiled proj. in target at rest system
     *                Rpjcms     ! recoiled proj. in cms
c
        record /ptcl/ Tglab,     ! target in lab.
     *                Tgpatr,    ! target in projectile at rest system
     *                Tgcms,     ! target  in cms
     *                Rtglab,    ! recoiled target in lab
     *                Rtgpatr,   ! recoiled target in proj. at rest system
     *                Rtgcms     ! recoiled target in cms
c
        record /ptcl/ Cmsp,      ! cms particle formed by proj. and targe 
c                                  in lab.
     *                Missingp   ! missing mass particle (rest of
c                                  two recoiled leadings) in cms.
        real*8  Efrs,      ! effective roots 
     *          Powerexp,  ! pw2 in x**pw2 exp(-x)dx exp. type Pt distri.
     *          Powerp,    ! pw in x/(x +p0)**pw dx power type Pt distri.
     *          Ptnorm,    ! average Pt for normalization (pion's at this E)
     *          Probpower, ! Probability of power type pt.
     *          Avncharged ! Average number of charge particles 
c                                  
        integer  Nnnb,    ! # of nn~
     *           Nkaon,   ! # of kaons
     *           Nddb,    ! # of DD~
     *           Npic,    ! # of pi+, pi-
     *           Nk0,     ! # of k0
     *           Nkch,    ! # of k+, k- ( Nkaon = Nkch + Nk0)
     *           Npi0,    ! # of pi 0
     *           Nch      ! # of all charged secondaries



        common /Zevhnv/  Pjlab, Pjtatr, Pjcms, Rpjlab, Rpjtatr,
     *                    Rpjcms, Tglab, Tgpatr, Tgcms, Rtglab,
     *                    Rtgpatr, Rtgcms, Cmsp, Missingp, 
     *                    Efrs, Powerexp, Powerp, Ptnorm, Probpower,
     *                    Avncharged, Nch,
     *                    Nnnb, Nkaon, Nddb, Npic, Nk0, Nkch, Npi0

==> Cosmos.uv4.12.tar.gz: cosmos/Zevhnv.h <==
c                    variables in Event generator
        record /ptcl/ Pjlab,     ! projectile in lab.
     *                Pjtatr,    ! projectile in target at rest system
     *                Pjcms,     ! projectile in cms
     *                Rpjlab,    ! recoiled proj. in lab
     *                Rpjtatr,   ! recoiled proj. in target at rest system
     *                Rpjcms     ! recoiled proj. in cms
c
        record /ptcl/ Tglab,     ! target in lab.
     *                Tgpatr,    ! target in projectile at rest system
     *                Tgcms,     ! target  in cms
     *                Rtglab,    ! recoiled target in lab
     *                Rtgpatr,   ! recoiled target in proj. at rest system
     *                Rtgcms     ! recoiled target in cms
c
        record /ptcl/ Cmsp,      ! cms particle formed by proj. and targe 
c                                  in lab.
     *                Missingp   ! missing mass particle (rest of
c                                  two recoiled leadings) in cms.
        real*8  Efrs,      ! effective roots 
     *          Powerexp,  ! pw2 in x**pw2 exp(-x)dx exp. type Pt distri.
     *          Powerp,    ! pw in x/(x +p0)**pw dx power type Pt distri.
     *          Ptnorm,    ! average Pt for normalization (pion's at this E)
     *          Probpower, ! Probability of power type pt.
     *          Avncharged ! Average number of charge particles 
c                                  
        integer  Nnnb,    ! # of nn~
     *           Nkaon,   ! # of kaons
     *           Nddb,    ! # of DD~
     *           Npic,    ! # of pi+, pi-
     *           Nk0,     ! # of k0
     *           Nkch,    ! # of k+, k- ( Nkaon = Nkch + Nk0)
     *           Npi0,    ! # of pi 0
     *           Nch,     ! # of all charged secondaries
     *           Neta     ! # of eta


        common /Zevhnv/  Pjlab, Pjtatr, Pjcms, Rpjlab, Rpjtatr,
     *                    Rpjcms, Tglab, Tgpatr, Tgcms, Rtglab,
     *                    Rtgpatr, Rtgcms, Cmsp, Missingp, 
     *                    Efrs, Powerexp, Powerp, Ptnorm, Probpower,
     *                    Avncharged, Nch,
     *                    Nnnb, Nkaon, Nddb, Npic, Nk0, Nkch, Npi0,
     *                    Neta
